genshi.filters

Package genshi :: Package filters |

# Package filters

Implementation of a number of stream filters.

Submodules
genshi.filters.html: Implementation of a number of stream filters. genshi.filters.i18n: Directives and utilities for internationalization and localization of templates. genshi.filters.transform: A filter for functional-style transformations of markup streams.

Variables
| __package__ = ``'``genshi.filters``'``